# mygui 0.0.7
## lgrid
+ A new Command that allows you to place a label in a grid. 
+ Simple and elegant implimentation as follows:
#
- lgrid({window_or_frame},{Text for label}, {Column Number},{Row Number})
- lgrid(root,"hello",1,5) Places a word 'hello' in row 1 column 5
#
Example script:

#

    import os
    from mygui import lgrid
    from tkinter import Tk
    root=Tk()
    root.minsize(300,100)
    lgrid(root,'Label placed in grid 0,0',0,0)
    lgrid(root,'Label placed in grid 1,1', 0,0)
    egrid(root,0,2)
    root.mainloop()

#

